@@ -404,6 +404,19 @@ class Node(BaseModel):
             gql_d_output[field_name] = val
         return gql_d_output
 
+    @staticmethod
+    def objs_to_str(obj_d: T.Dict[str, T.Any]) -> T.Dict[str, T.Any]:
+        if not obj_d:
+            return obj_d
+        cleaned_set_d = {}
+        for key, val in obj_d.items():
+            if isinstance(val, BaseModel):
+                val = val.json()
+            if type(val) is dict:
+                val = json.dumps(val)
+            cleaned_set_d[key] = val
+        return cleaned_set_d
+
     async def _update(
         self,
         *,
@@ -413,6 +426,9 @@ class Node(BaseModel):
         print_update_d: bool = False,
     ) -> bool:
         set_d, remove_d = self.base_set_remove_d(to_set=to_set, to_remove=to_remove)
+        # turn base models or dicts into strs
+        set_d = self.objs_to_str(set_d)
+        remove_d = self.objs_to_str(remove_d)
         return await self.update_from_set_remove_ds(
             set_d=set_d,
             remove_d=remove_d,
